@@ -79,6 +79,7 @@ sub awx_wx_config_data {
     $self->awx_w32_find_setup_dir( $data{cxxflags} ); # for awx_grep_dlls
 
     $data{dlls} = $self->awx_grep_dlls( $orig_libdir, $digits, $self->awx_is_monolithic );
+    $data{w32builtins} = $self->{w32builtins};
     $data{version} = $digits;
 
     $self->{awx_data} = \%data;
@@ -126,6 +127,13 @@ sub awx_w32_ldflags {
 	
 }
 
-sub awx_w32_cppflags { return ''; }
+sub awx_w32_cppflags {
+	my $self = shift;
+	my $cppflags = '';
+	for ( qw( -D_USE_32BIT_TIME_T ) ) {
+		$cppflags .= qq( $_) if $Config{ccflags} =~ /$_/;
+	}
+	return $cppflags;
+}
 
 1;
